stations
--------
.. module:: weatherDB.stations

StationsP
^^^^^^^^^
.. autoclass:: weatherDB.stations.StationsP

  .. autoclasstoc::

StationsT
^^^^^^^^^
.. autoclass:: weatherDB.stations.StationsT

  .. autoclasstoc::

StationsET
^^^^^^^^^^
.. autoclass:: weatherDB.stations.StationsET

  .. autoclasstoc::

StationsPD
^^^^^^^^^^
.. autoclass:: weatherDB.stations.StationsPD

  .. autoclasstoc::

GroupStations
^^^^^^^^^^^^^
.. autoclass:: weatherDB.stations.GroupStations

  .. autoclasstoc::

StationsBase...
^^^^^^^^^^^^^^^
Those are the base stations classes on which the real stations classes above depend on.
None of them is working on its own, because the class variables are not yet set correctly.

.. autoclass:: weatherDB.stations.StationsBase.StationsBase

  .. autoclasstoc::

.. autoclass:: weatherDB.stations.StationsBaseTET.StationsBaseTET

   .. autoclasstoc::